@@ -42,6 +42,8 @@ return [
     'events' => \Mtc\Orders\Providers\OrderEventServiceProvider::class,
     'routing' => \Mtc\Orders\Providers\OrderRouteServiceProvider::class,
 
+    'send_order_status_email_listener' => \Mtc\Orders\Listeners\SendOrderStatusEmail::class,
+
     /*
     |--------------------------------------------------------------------------
     | Status action bindings
@@ -55,6 +57,7 @@ return [
         'confirmed' => 1,
         'shipped' => 3,
         'part-shipped' => 4,
+        'part-refunded' => 5,
         'refunded' => 6,
         'cancelled' => 8,
     ],
@@ -206,7 +209,7 @@ return [
     | This setting links to shipment creation from view order page
     |
     */
-    'shipment_creation' => true,
+    'shipment_creation' => false,
     'manual_shipment_value' => false,
     'shipment_factory' => \Mtc\Orders\Factories\ShipmentFactory::class,
     'shipment_packaging_layout' => 'basic',
@@ -262,4 +265,61 @@ return [
     */
 
     'auto_capture_deferred_payments_on_status' => false,
+
+    /*
+    |--------------------------------------------------------------------------
+    | Tracking info fields
+    |--------------------------------------------------------------------------
+    |
+    | If site doesn't use courier API and shipment management a simple
+    | interface is offered for managing tracking information.
+    | This config allows setting fields that would be available in admin.
+    | When set they are saved to order.tracking_data and are available in templates.
+    |
+    */
+    'tracking_fields' => [
+        [
+            'name' => 'courier',
+            'type' => 'select',
+            'label' => 'Courier',
+            'values' => [
+                'dpd' => 'DPD',
+                'dhl' => 'DHL',
+                'ups' => 'UPS',
+            ],
+        ],
+        [
+            'name' => 'code',
+            'type' => 'text',
+            'label' => 'Tracking Code',
+        ],
+    ],
+
+    /*
+    |--------------------------------------------------------------------------
+    | Order status emails
+    |--------------------------------------------------------------------------
+    |
+    | Parts to include within order status emails
+    |
+    */
+    'order_email_parts' => [
+        'image' => true,
+        'sku' => false,
+    ],
+
+    /*
+    |--------------------------------------------------------------------------
+    | Order status email copies
+    |--------------------------------------------------------------------------
+    |
+    | This config allows enabling status email copies to SHOP_EMAIL
+    | - 'confirmed' triggers a copy for "Confirmed" status
+    | - 'all_statuses' triggers a copy for all order statuses (including "Confirmed")
+    |
+    */
+    'admin_copy' => [
+        'confirmed' => true,
+        'all_statuses' => false,
+    ],
 ];
